@@ -17,8 +17,8 @@ import os.path
 
 # Constants ====================================================================
 
-FTP_BASENAME_GRCH37 = 'GCF_000001405.25.bgz'
-FTP_BASENAME_GRCH38 = 'GCF_000001405.39.bgz'
+FTP_BASENAME_GRCH37 = 'GCF_000001405.25.gz'
+FTP_BASENAME_GRCH38 = 'GCF_000001405.39.gz'
 VCF_GRCH37 = os.environ.get(
     'PYDBSNP_VCF_GRCH37', 
     os.path.join(os.path.dirname(__file__), FTP_BASENAME_GRCH37)
@@ -33,11 +33,11 @@ BUILD_TO_VCF = {
 }
 RSID_GRCH37 = os.environ.get(
     'PYDBSNP_RSID_GRCH37', 
-    os.path.join(os.path.dirname(__file__), 'GCF_000001405.25.rsid.bgz')
+    os.path.join(os.path.dirname(__file__), 'GCF_000001405.25.rsid.gz')
 )
 RSID_GRCH38 = os.environ.get(
     'PYDBSNP_RSID_GRCH38', 
-    os.path.join(os.path.dirname(__file__), 'GCF_000001405.39.rsid.bgz')
+    os.path.join(os.path.dirname(__file__), 'GCF_000001405.39.rsid.gz')
 )
 BUILD_TO_RSID = {
     'hg19': RSID_GRCH37, 'GRCh37': RSID_GRCH37,
